@@ -1,4 +1,6 @@
-from typing import Any, Dict
+from __future__ import annotations
+
+from typing import Any
 
 import fastjsonschema
 
@@ -13,20 +15,20 @@ class VPP001:
     family = "validate-pyproject"
 
     @staticmethod
-    def check(pyproject: Dict[str, Any]) -> str:
+    def check(pyproject: dict[str, Any]) -> str:
         validator = api.Validator()
         try:
             validator(pyproject)
-            return ""
         except fastjsonschema.JsonSchemaValueException as e:
             return f"Invalid pyproject.toml! Error: {e}"
+        return ""
 
 
-def repo_review_checks() -> Dict[str, VPP001]:
+def repo_review_checks() -> dict[str, VPP001]:
     return {"VPP001": VPP001()}
 
 
-def repo_review_families(pyproject: Dict[str, Any]) -> Dict[str, Dict[str, str]]:
+def repo_review_families(pyproject: dict[str, Any]) -> dict[str, dict[str, str]]:
     has_distutils = "distutils" in pyproject.get("tool", {})
     plugin_list = plugins.list_from_entry_points(
         lambda e: e.name != "distutils" or has_distutils
